@@ -1,9 +1,7 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE Rank2Types #-}
 {-# LANGUAGE DeriveDataTypeable #-}
-#if __GLASGOW_HASKELL__ >= 704
 {-# LANGUAGE DeriveGeneric #-}
-#endif
 {-# OPTIONS_HADDOCK not-home #-}
 -----------------------------------------------------------------------------
 -- |
@@ -55,9 +53,7 @@ module Numeric.Interval.NonEmpty.Internal
 
 import Control.Exception as Exception
 import Data.Data
-#if __GLASGOW_HASKELL__ >= 704
 import GHC.Generics
-#endif
 import Prelude hiding (null, elem, notElem)
 
 import qualified Data.Semigroup
@@ -79,22 +75,12 @@ import qualified Data.Semigroup
 -- >>> let compose2 = fmap . fmap
 -- >>> let commutative op a b = (a `op` b) == (b `op` a)
 --
--- -- Eta expansion needed for GHC-7.6
--- >>> :set -fno-warn-deprecations
--- >>> let elem x xs = Numeric.Interval.NonEmpty.Internal.elem x xs
--- >>> let notElem x xs = Numeric.Interval.NonEmpty.Internal.notElem x xs
+-- >>> :set -Wno-deprecations
+-- >>> let elem = Numeric.Interval.NonEmpty.Internal.elem
+-- >>> let notElem = Numeric.Interval.NonEmpty.Internal.notElem
 
 data Interval a = I !a !a deriving
-  ( Eq, Ord
-  , Data
-  , Typeable
-#if __GLASGOW_HASKELL__ >= 704
-  , Generic
-#if __GLASGOW_HASKELL__ >= 706
-  , Generic1
-#endif
-#endif
-  )
+  (Eq, Ord, Data, Generic, Generic1)
 
 -- | 'Data.Semigroup.<>' is 'hull'
 instance Ord a => Data.Semigroup.Semigroup (Interval a) where
@@ -437,8 +423,9 @@ divZero x@(I a b)
 
 -- | Fractional instance for intervals.
 --
--- prop> ys /= singleton 0 ==> conservative2 ((/) :: Double -> Double -> Double) (/) xs ys
--- prop> xs /= singleton 0 ==> conservative (recip :: Double -> Double) recip xs
+-- -- The property tests below are currently disabled (#66).
+-- -- prop> ys /= singleton 0 ==> conservative2 ((/) :: Double -> Double -> Double) (/) xs ys
+-- -- prop> xs /= singleton 0 ==> conservative (recip :: Double -> Double) recip xs
 instance (Fractional a, Ord a) => Fractional (Interval a) where
   -- TODO: check isNegativeZero properly
   x / y@(I a b)
@@ -806,7 +793,8 @@ deflate x i@(I a b) | a' <= b'  = I a' b'
 -- >>> scale (-2.0) (-1.0 ... 1.0)
 -- -2.0 ... 2.0
 --
--- prop> abs x >= 1 ==> (scale (x :: Double) i) `contains` i
+-- -- The property test below is currently disabled (#66).
+-- -- prop> abs x >= 1 ==> (scale (x :: Double) i) `contains` i
 -- prop> forAll (choose (0,1)) $ \x -> abs x <= 1 ==> i `contains` (scale (x :: Double) i)
 scale :: (Fractional a, Ord a) => a -> Interval a -> Interval a
 scale x i = a ... b where
